diff graal/com.oracle.max.cri/src/com/oracle/max/cri/ci/CiAddress.java @ 5506:56860d3f9f39

More refactorings and renamings in preparation of ci/ri split.
author Thomas Wuerthinger <thomas.wuerthinger@oracle.com>
date Thu, 07 Jun 2012 18:12:01 +0200
parents 452f91ebdb54
children dc71b06d09f8
line wrap: on
line diff
--- a/graal/com.oracle.max.cri/src/com/oracle/max/cri/ci/CiAddress.java	Thu Jun 07 17:25:52 2012 +0200
+++ b/graal/com.oracle.max.cri/src/com/oracle/max/cri/ci/CiAddress.java	Thu Jun 07 18:12:01 2012 +0200
@@ -31,25 +31,25 @@
  * a displacement and a scale. Note that the base and index registers may be a variable that will get a register assigned
  * later by the register allocator.
  */
-public final class CiAddress extends CiValue {
+public final class CiAddress extends RiValue {
     private static final long serialVersionUID = -1003772042519945089L;
 
     /**
      * A sentinel value used as a place holder in an instruction stream for an address that will be patched.
      */
-    public static final CiAddress Placeholder = new CiAddress(RiKind.Illegal, CiValue.IllegalValue);
+    public static final CiAddress Placeholder = new CiAddress(RiKind.Illegal, RiValue.IllegalValue);
 
     /**
      * Base register that defines the start of the address computation.
      * If not present, is denoted by {@link CiValue#IllegalValue}.
      */
-    public CiValue base;
+    public RiValue base;
 
     /**
      * Index register, the value of which (possibly scaled by {@link #scale}) is added to {@link #base}.
      * If not present, is denoted by {@link CiValue#IllegalValue}.
      */
-    public CiValue index;
+    public RiValue index;
 
     /**
      * Scaling factor for indexing, dependent on target operand size.
@@ -66,7 +66,7 @@
      * @param kind the kind of the value being addressed
      * @param base the base register
      */
-    public CiAddress(RiKind kind, CiValue base) {
+    public CiAddress(RiKind kind, RiValue base) {
         this(kind, base, IllegalValue, Scale.Times1, 0);
     }
 
@@ -76,7 +76,7 @@
      * @param base the base register
      * @param displacement the displacement
      */
-    public CiAddress(RiKind kind, CiValue base, int displacement) {
+    public CiAddress(RiKind kind, RiValue base, int displacement) {
         this(kind, base, IllegalValue, Scale.Times1, displacement);
     }
 
@@ -89,7 +89,7 @@
      * @param scale the scaling factor
      * @param displacement the displacement
      */
-    public CiAddress(RiKind kind, CiValue base, CiValue index, Scale scale, int displacement) {
+    public CiAddress(RiKind kind, RiValue base, RiValue index, Scale scale, int displacement) {
         super(kind);
         this.base = base;
         this.index = index;
@@ -31,25 +31,25 @@
     /**
      * Base register that defines the start of the address computation.
-     * If not present, is denoted by {@link CiValue#IllegalValue}.
+     * If not present, is denoted by {@link RiValue#IllegalValue}.
      */
@@ -31,25 +31,25 @@
     /**
      * Index register, the value of which (possibly scaled by {@link #scale}) is added to {@link #base}.
-     * If not present, is denoted by {@link CiValue#IllegalValue}.
+     * If not present, is denoted by {@link RiValue#IllegalValue}.
      */